@@ -348,6 +348,9 @@ def go(batch=False):
         os.symlink(os.path.join(source_cwd, AGENT_NAME),
                    os.path.join(home_path, AGENT_NAME))
 
+        sockfile_path = os.path.join(home_path, 'run')
+        if not os.path.exists(sockfile_path):
+            os.mkdir(sockfile_path)
         newenv['whatap.enabled'] = 'True'
         newenv['WHATAP_PID_FILE'] = file_name
         process = subprocess.Popen(['./{0}'.format(AGENT_NAME), '-t', '3', '-d', '1'],
