@@ -27,11 +27,13 @@ class UdpSession(object):
         from whatap.conf.configure import Configure as conf
         home = 'WHATAP_HOME'
         whatap_home = os.environ.get(home,'')
-        unix_socket_path = os.path.join(whatap_home, conf.unix_socket)
-        
-        if conf.unix_socket_enabled and os.path.exists(unix_socket_path):
+
+        if conf.unix_socket_enabled == True :
+            unix_socket_path = os.path.join(whatap_home, conf.unix_socket)
+            while not os.path.exists(unix_socket_path):
+                time.sleep(0.1)
             with cls.socket_lock:
-                tmp_socket_path = os.path.join('/tmp/whatap', 'whatap.{}.sock'.format(os.getpid()))
+                tmp_socket_path = os.path.join(whatap_home,'run', 'whatap.{}.sock'.format(os.getpid()))
                 if os.path.exists(tmp_socket_path):
                     os.remove(tmp_socket_path)
                 prefix=os.path.split(tmp_socket_path)[0]
@@ -119,7 +121,7 @@ class UdpSession(object):
     def send(cls, packet_type, ctx):
         s = cls.s
         if not s:
-            s = cls.udp()
+            return
 
         # for name, value in PacketTypeEnum.__dict__.items():
         #     if value == packet_type:
@@ -127,7 +129,8 @@ class UdpSession(object):
 
         try:
             from datetime import datetime
-            s.sendall(b''.join(cls.buffer_arr))
+            sendbuf = b''.join(cls.buffer_arr)
+            s.send(sendbuf)
         except ConnectionRefusedError as e:
             logging.debug(e, extra={'id': 'WA911'}, exc_info=True)
             cls.udp()
@@ -224,10 +227,12 @@ class UdpSession(object):
             elif param_id == ParamDef.GET_DBCONN_POOL:
                 
                 stats = TraceContextManager.getDBConnPool()
-                pid = os.getpid()
-                strdbpool = '{}|{{}}|{{}}|{{}}'.format(pid)
-                datas = [','.join([strdbpool.format( k,act,inact) for k,(act,inact) in stats.items()])]
-                cls.send_packet(PacketTypeEnum.DBCONN_POOL, None, datas)
+                if stats:
+                    pid = os.getpid()
+                    strdbpool = '{}|{{}}|{{}}|{{}}'.format(pid)
+                    datas = [','.join([strdbpool.format( k,act,inact) for k,(act,inact) in stats.items()])]
+                    cls.send_packet(PacketTypeEnum.DBCONN_POOL, None, datas)
+
                 return
 
             cls.send_packet(PacketTypeEnum.TX_PARAM, None, datas)
